@@ -30,6 +30,7 @@ def read_nc_emodnet(path, clean_data=True):
                 Input dataset.
             clean_data_in: bool
                 It indicates if "_DM" variables should be deleted.
+
         Returns
         -------
             ds_out: xarray.Dataset
@@ -44,6 +45,7 @@ def read_nc_emodnet(path, clean_data=True):
         else:
             ds_out = ds_in
 
+        # ds_out = ds_out.drop_sel('DEPTH')
         if 'LATITUDE' in ds_in.variables.keys():
             ds_out = ds_out.drop('LATITUDE')
         if 'LONGITUDE' in ds_in.variables.keys():
@@ -65,14 +67,20 @@ def read_nc_emodnet(path, clean_data=True):
 
     # Save ds into a WaterFrame
     wf.metadata = dict(ds.attrs)
-    wf.data = ds.to_dataframe()
+    # Add network
+    wf.metadata['network'] = 'emodnet'
 
+    wf.data = ds.to_dataframe()
     # Harmonize data
     wf.data.reset_index(inplace=True)
-    wf.data.set_index(['DEPH', 'TIME'], inplace=True)
-    wf.data.index.rename(['DEPTH', 'TIME'], inplace=True)
-    del wf.data['DEPTH']
-    wf.data.rename(columns={'DEPH_QC':'DEPTH_QC'}, inplace=True)
+
+    try:
+        wf.data.set_index(['DEPH', 'TIME'], inplace=True)
+        wf.data.index.rename(['DEPTH', 'TIME'], inplace=True)
+        del wf.data['DEPTH']
+        wf.data.rename(columns={'DEPH_QC':'DEPTH_QC'}, inplace=True)
+    except KeyError:
+        wf.data.set_index(['DEPTH', 'TIME'], inplace=True)
 
     for variable in ds.variables:
         wf.vocabulary[variable] = dict(ds[variable].attrs)
