@@ -8,10 +8,12 @@ class WaterFrame:
     from .analysis import (
         min, max, copy, use_only, rename, corr, max_diff, time_intervals, resample, slice_time,
         info_metadata, info_vocabulary, drop)
-    from .output import to_nc, to_pkl, to_json
+    from .output import to_nc, to_pkl, to_json, to_es, metadata_to_html, to_csv
     from .plot import plot_timeseries, plot_timebar, plot_hist, plot
-    from .qc import qc_flat_test, qc_range_test, qc_spike_test
-    from .iplot import iplot_location, iplot_timeseries
+    from .qc import qc_flat_test, qc_range_test, qc_spike_test, qc_replace
+    from .iplot import (
+        iplot_location, iplot_timeseries, iplot, iplot_scatter, iplot_line,
+        iplot_data_intervals)
 
     def __init__(self, df=None, metadata=None, vocabulary=None):
         """ Constructor """
@@ -62,22 +64,25 @@ class WaterFrame:
             min_dict = self.min(parameter)
             max_dict = self.max(parameter)
             value_mean = self.data[parameter].mean()
-            # min value string
-            parameters_message += f"\n    - Min value: {min_dict[parameter]}"
-            for key, value in min_dict.items():
-                if key == parameter:
-                    continue
-                else:
-                    parameters_message += f"\n      - {key}: {value}"
-            # max value string
-            parameters_message += f"\n    - Max value: {max_dict[parameter]}"
-            for key, value in max_dict.items():
-                if key == parameter:
-                    continue
-                else:
-                    parameters_message += f"\n      - {key}: {value}"
-            # mean value string
-            parameters_message += f"\n    - Mean value: {value_mean}"
+            if min_dict is not None and max_dict is not None:
+                # min value string
+                parameters_message += f"\n    - Min value: {min_dict[parameter]}"
+                for key, value in min_dict.items():
+                    if key == parameter:
+                        continue
+                    else:
+                        parameters_message += f"\n      - {key}: {value}"
+                # max value string
+                parameters_message += f"\n    - Max value: {max_dict[parameter]}"
+                for key, value in max_dict.items():
+                    if key == parameter:
+                        continue
+                    else:
+                        parameters_message += f"\n      - {key}: {value}"
+                # mean value string
+                parameters_message += f"\n    - Mean value: {value_mean}"
+            else:
+                parameters_message += "\n    - Parameter without values."
 
         message = size_message + "\n" + parameters_message
 
